@@ -32,9 +32,9 @@ class Parameters:
         8: Unknown("ID_SU_FrkdAl"),
         9: Unknown("ID_Einst_HReg_akt"),
         10: Unknown("ID_Einst_HzHwMAt_akt"),
-        11: Celsius("ID_Einst_HzHwHKE_akt"),
-        12: Celsius("ID_Einst_HzHKRANH_akt"),
-        13: Celsius("ID_Einst_HzHKRABS_akt"),
+        11: Celsius("ID_Einst_HzHwHKE_akt", True),
+        12: Celsius("ID_Einst_HzHKRANH_akt", True),
+        13: Celsius("ID_Einst_HzHKRABS_akt", True),
         14: Unknown("ID_Einst_HzMK1E_akt"),
         15: Unknown("ID_Einst_HzMK1ANH_akt"),
         16: Unknown("ID_Einst_HzMK1ABS_akt"),
